SELECT 10/pyro-sync - Criterion.rs

## SELECT 10/pyro-sync

#### Additional Statistics:

| Lower bound | Estimate | Upper bound
--- | --- | --- | ---
R² | 0.0001753 | 0.0001816 | 0.0001746
Mean | 4.3102 ms | 4.3844 ms | 4.4627 ms
Std. Dev. | 318.23 µs | 393.62 µs | 463.08 µs
Median | 4.2682 ms | 4.3610 ms | 4.4254 ms
MAD | 235.47 µs | 369.92 µs | 484.19 µs

#### Additional Plots:

- Typical
- Mean
- Std. Dev.
- Median
- MAD

#### Understanding this report:

The plot on the left displays the average time per iteration for this benchmark. The shaded region shows the estimated probability of an iteration taking a certain amount of time, while the line shows the mean. Click on the plot for a larger view showing the outliers.

The plot on the right shows the average time per iteration for the samples. Each point represents one sample.

See the documentation for more details on the additional statistics.